:mod:`fugw.mappings`
========================

Most likely, this is the module you want to use.
It comprises 2 main classes: :class:`fugw.mappings.FUGW`
and :class:`fugw.mappings.FUGWSparse`,
each of which comes with ``.fit()``, ``transform()`` and ``.inverse_transform()``
methods to easily fit your FUGW models and apply them to new data.

.. toctree::

   mappings.FUGW.rst
   mappings.FUGWSparse.rst
